#!/bin/sh
#
# -----------------------------------------------------------------------------
#
# ZenBuild script for Pure-ftpd
# ===========================
# Author:	Thibaud GUERIN <guth@ploposor.com>
# Maintainer : Son|c (emmanuel.bailleul@cegetel.net)
# Need:		libmysqlclient for compiling time
# URL:		http://download.pureftpd.org/pub/pure-ftpd/releases/pure-ftpd-1.0.27.tar.bz2

soft='pure-ftpd'
softversion='1.0.27'
packageversion='64.1'

arch='i486'
cpu='i686'

buildir=$(pwd)
srcpkg="$buildir/${soft}-${softversion}.tar.bz2"
src="$buildir/${soft}-${softversion}"
package="${soft}-${softversion}-${arch}-${packageversion}"
dest="$buildir/${package}"


cd $buildir
rm -rf $src


#
# Extract the tar ball, patch and modify
#
echo "Extracting the program tarball..."
tar -xf $srcpkg

rm -f $dest.tgz
rm -rf $dest
mkdir -p $dest
#chown -R root:root .
export CFLAGS="-O2 -march=$arch -mtune=$cpu"
export CXFLAGS="-O2 -march=i486 -mtune=$cpu"

cd $src


echo "Building ..."
# to have it in you own language:
# --with-language="english|german|romanian|french|polish|spanish|danish|dutch|italian|brazilian-portuguese|slovak|korean|swedish|norwegian|russian|traditional-chinese|simplified-chinese|czech|turkish|hungarian|catalan"

#to remove mysql dep : delete "--with-mysql \" line

./configure \
--prefix=/usr \
--localstatedir=/var \
--sysconfdir=/etc \
--mandir=/usr/man \
--with-puredb \
--with-extauth \
--with-throttling \--with-ratios \
--with-quotas \
--with-ftpwho \
--with-largefile \
--with-virtualhosts \
--with-diraliases \
--with-peruserlimits \
--with-ldap \
--with-mysql \
--with-privsep \
--with-tls

make
make install DESTDIR=$dest
cd ..

mkdir -p $dest/usr/bin
mkdir -p $dest/usr/man/man1

chown -R root.root $dest

mkdir -p $dest/usr/share/applications
mkdir -p $dest/usr/share/icons/hicolor/48x48/apps

# Copy icon
cp $buildir/$soft.png $dest/usr/share/icons/hicolor/48x48/apps/

( cd $dest
  find . | xargs file | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded
)
( cd $dest/usr/man
  find . -name "*.?" | xargs gzip -9
)

## configuration file
mkdir -p $dest/etc
cd $src
cp -a configuration-file/pure-ftpd.conf $dest/etc/pure-ftpd.conf.new
cp configuration-file/pure-config.p[ly] $dest/usr/bin/
chmod 555 $dest/usr/bin/pure-config.p[ly]


## --- DOCUMENTATION ---
echo "Building Doc"
rm -rf $dest/usr/share/doc
mkdir -p $dest/usr/doc/$soft-$softversion

cd $src
cp -a AUTHORS CONTACT COPYING Changelog FAQ HISTORY INSTALL NEWS README* \
THANKS pureftpd* pure-ftpd.spec $dest/usr/doc/$soft-$softversion


cd ..
chown -R root.root $dest/usr/doc/$soft-$softversion/*
chmod -R a-ws $dest/usr/doc/$soft-$softversion/*

# Compress the man pages
gzip -9f $dest/usr/man/*/*


# --- PACKAGE DESCRIPTION ---
mkdir -p $dest/install

cat <<EOF > $dest/install/slack-desc
#       |-----handy-ruler------------------------------------------------------|
$soft: Pure-ftpd (ftpd server)
$soft: 
$soft: Pure-FTPd is a free (BSD), secure, production-quality and
$soft: standard-conformant FTP server.
$soft: 
$soft: 
$soft: 
$soft: 
$soft: 
$soft: 
$soft: 
EOF



# Create .desktop for compatibility
cat >$dest/usr/share/applications/$soft.desktop <<"EOF"
[Desktop Entry]
Encoding=UTF-8
Exec=pure-ftpd
Icon=pure-ftpd.png
Type=Application
Categories=Application;Network;
Name=Pure-ftpd
GenericName=ftp server
EOF



mkdir -p $dest/usr/src/$soft-$softversion
cp $buildir/build-$soft.sh $dest/usr/src/$soft-$softversion

# --- OWNERSHIP, RIGHTS ---

chmod -R o-w $dest

# Create doinst
echo "config() {
  NEW=\"\$1\"
  OLD=\"\`dirname \$NEW\`/\`basename \$NEW .new\`\"
  # If there's no config file by that name, mv it over:
  if [ ! -r \$OLD ]; then
    mv \$NEW \$OLD
  elif [ \"\`cat \$OLD | md5sum\`\" = \"\`cat \$NEW | md5sum\`\" ]; then # toss the redundant copy
    rm \$NEW
  fi
  # Otherwise, we leave the .new copy for the admin to consider...
}
config etc/pure-ftpd.conf.new" > $dest/install/doinst.sh

#------------------( Create The *.dep Files )
cd $dest
depfinder $dest > $buildir/$package.dep

# --- BUILDING ---

echo "Build package"
cd $dest
/sbin/makepkg -l y -c n $dest.txz

# computes the md5sum signature for the package
cd $buildir
md5sum $package.txz > $package.md5

echo "http://download.pureftpd.org/pub/pure-ftpd/releases/pure-ftpd-$softversion.tar.gz" > $package.src
echo "http://download.zenwalk.org/people/emmanuel/pure-ftpd-$softversion/build-$soft.sh" >> $package.src

#Private use
echo "extra/n" > $package.cat
